mmappcomponents/harvester/server/src/mpxharvesterengine.cpp
branchRCL_3
changeset 30 6f9f6e99a23e
parent 23 4740b34b83ce
--- a/mmappcomponents/harvester/server/src/mpxharvesterengine.cpp	Tue May 11 16:40:32 2010 +0300
+++ b/mmappcomponents/harvester/server/src/mpxharvesterengine.cpp	Tue May 25 13:14:13 2010 +0300
@@ -35,7 +35,7 @@
 #include "mpxharvesterengine.h"
 #include "mpxfsformatmonitor.h"
 #include "mpxmediaremovalmonitor.h"
-#include "mpxusbeventhandler.h"
+#include "mpxconnectioneventhandler.h"
 #include "mpxharvesterfilehandler.h"
 #include "mpxharvesterengineobserver.h"
 #include "mpxhvsmsg.h"
@@ -60,7 +60,7 @@
 
     delete iFormatMonitor;
     delete iMediaRemovalMonitor;
-    delete iUSBMonitor;
+    delete iConnectionMonitor;
 
     delete iFileHandler;
     iFsSession.Close();
@@ -101,8 +101,8 @@
     iMediaRemovalMonitor = CMPXMediaRemovalMonitor::NewL(
         removableDrive, iFsSession, *this );
 
-    // USB Event monitor
-    iUSBMonitor = CMPXUsbEventHandler::NewL( *this );
+    // Connection Event monitor
+    iConnectionMonitor = CMPXConnectionEventHandler::NewL( *this );
 
 
     // File handler to handle file related events
@@ -426,7 +426,7 @@
     // wont be able to open the db anyways.
     //
     iFormatMonitor->PollStatus();
-    iUSBMonitor->PollStatus();
+    iConnectionMonitor->PollStatus();
     }
 
 // ---------------------------------------------------------------------------